@@ -33,10 +33,15 @@ labels = {
 }
 
 # TODO: Add support for hclustering based explanations where we sort the leaf order by magnitude and then show the dendrogram to the left
-def beeswarm(shap_values, max_display=10, order=Explanation.abs.mean(0),
+# def beeswarm(shap_values, max_display=10, order=Explanation.abs.mean(0),
+#              clustering=None, cluster_threshold=0.5, color=None,
+#              axis_color="#333333", alpha=1, show=True, log_scale=False,
+#              color_bar=True, plot_size="auto", color_bar_label="Feature value"):
+def beeswarm(base_values, shap_values, features, feature_names, max_display=10, order=Explanation.abs.mean(0),
              clustering=None, cluster_threshold=0.5, color=None,
              axis_color="#333333", alpha=1, show=True, log_scale=False,
              color_bar=True, plot_size="auto", color_bar_label="Feature value"):
+
     """Create a SHAP beeswarm plot, colored by feature values when they are provided.
 
     Parameters
@@ -56,7 +61,7 @@ def beeswarm(shap_values, max_display=10, order=Explanation.abs.mean(0),
     """
 
     # support passing an explanation object
-    if True:#str(type(shap_values)).endswith("Explanation'>"):
+    if False and str(type(shap_values)).endswith("Explanation'>"):
         if len(shap_values.shape) == 1:
             raise ValueError(
                 "The beeswarm plot does not support plotting a single instance, please pass "
@@ -77,6 +82,7 @@ def beeswarm(shap_values, max_display=10, order=Explanation.abs.mean(0),
         # if out_names is None: # TODO: waiting for slicer support
         #     out_names = shap_exp.output_names
 
+    values=shap_values
     order = convert_ordering(order, values)
     
 
@@ -519,6 +525,7 @@ def summary_legacy(shap_values, features=None, feature_names=None, max_display=N
 
     if use_log_scale:
         pl.xscale('symlog')
+        pl.rcParams['font.sans-serif'] = ['SimSun']
 
     # plotting SHAP interaction values
     if not multi_class and len(shap_values.shape) == 3:
@@ -571,6 +578,7 @@ def summary_legacy(shap_values, features=None, feature_names=None, max_display=N
         )
         pl.xlim((slow, shigh))
         pl.xlabel("")
+        pl.rcParams['font.sans-serif'] = ['SimHei']  # 用来正常显示中文标签
         title_length_limit = 11
         pl.title(shorten_text(feature_names[sort_inds[0]], title_length_limit))
         for i in range(1, min(len(sort_inds), max_display)):
@@ -595,6 +603,7 @@ def summary_legacy(shap_values, features=None, feature_names=None, max_display=N
             pl.title(shorten_text(feature_names[ind], title_length_limit))
         pl.tight_layout(pad=0, w_pad=0, h_pad=0.0)
         pl.subplots_adjust(hspace=0, wspace=0.1)
+        pl.rcParams['font.sans-serif'] = ['SimSun']
         if show:
             pl.show()
         return
@@ -620,7 +629,8 @@ def summary_legacy(shap_values, features=None, feature_names=None, max_display=N
     elif plot_size is not None:
         pl.gcf().set_size_inches(8, len(feature_order) * plot_size + 1.5)
     pl.axvline(x=0, color="#999999", zorder=-1)
-    # pl.rcParams['font.sans-serif'] = ['SimSun']
+    pl.rcParams['font.sans-serif'] = ['SimSun']
+
 
     if plot_type == "dot":
         for pos, i in enumerate(feature_order):
