@@ -25,7 +25,8 @@ else:
 
 import warnings
 import re
-from .utils._legacy import convert_to_link, Instance, Model, Data, DenseData, Link, hclust_ordering, draw_additive_plot
+from .utils._legacy import convert_to_link, Instance, Model, Data, DenseData, Link, hclust_ordering
+from .utils._force_matplotlib import draw_additive_plot
 
 def force(base_value, shap_values=None, features=None, feature_names=None, out_names=None, link="identity",
           plot_cmap="RdBu", matplotlib=False, show=True, figsize=(20,3), ordering_keys=None, ordering_keys_time_format=None,
