@@ -29,9 +29,9 @@ def kmeans_blocks(x,box_num=3):
     km = KMeans(n_clusters=len_clocks-1, random_state=666)
     y_pre = km.fit_predict(X)
     # 使用Calinski-Harabasz Index评估的聚类分数: 分数越高，表示聚类的效果越好
-    if km.cluster_centers_.size > 1:  # 聚类类别大于1
-        kmeans_score = calinski_harabaz_score(X, y_pre)
-        print("聚类效果评分：{}".format(kmeans_score))
+    # if km.cluster_centers_.size > 1:  # 聚类类别大于1
+    #     kmeans_score = calinski_harabaz_score(X, y_pre)
+    #     print("聚类效果评分：{}".format(kmeans_score))
     tb = km.cluster_centers_.reshape([-1])
     tb.sort()
     blocks = np.concatenate([[-np.inf],tb,[np.inf]])
