@@ -21,16 +21,15 @@ shap_values.values=np.array([2,4,-3])
 # pl.rcParams['font.sans-serif'] = ['SimSun']
 
 # 1.单特征
-# card_explanations.waterfall(shap_values)
-# card_explanations.waterfall(expected_value=10, shap_values=np.array([2,4,-3]), features=[30,'女',167],
+# card_explanations.waterfall(base_value=10, shap_values=np.array([2,4,-3]), features=np.array([30,'女',167]),
 #                                         feature_names=['年龄','性别','身高'])
 
 
 # 2.单特征
-card_explanations.force(
-    base_value=10, shap_values=np.array([2,4,-3]), features=[30,'女',167],
-                                        feature_names=['年龄','性别','身高'],matplotlib=True)
+# card_explanations.force(
+#     base_value=10, shap_values=np.array([2,4,-3]), features=[30,'女',167],
+#                                         feature_names=['年龄','性别','身高'],matplotlib=True)
 
-# 3.数据集特征贡献
-# card_explanations.summary_plot(shap_values=np.array([[2,4,-3]]), features=[[30,'女',167]],
-#                                         feature_names=['年龄','性别','身高'])
\ No newline at end of file
+# # 3.数据集特征贡献
+card_explanations.beeswarm(base_values=561,shap_values=np.array([[2,4,-3]]), features=[[30,'女',167]],
+                                        feature_names=['年龄','性别','身高'])
\ No newline at end of file
